==> carpet-addons-not-found-1.17.1-2.1.0-sources.jar: carpetaddonsnotfound/mixins/PistonExtensionBlockMixin.java <==
package carpetaddonsnotfound.mixins;

import carpetaddonsnotfound.unobtainableblocks.UnobtainableBlockProcessor;
import com.llamalad7.mixinextras.sugar.Local;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;
import java.util.List;
import net.minecraft.class_1799;
import net.minecraft.class_2667;
import net.minecraft.class_2669;
import net.minecraft.class_2680;
import net.minecraft.class_47;

@Mixin(class_2667.class)
public abstract class PistonExtensionBlockMixin {
  @Inject(
          method = "getDroppedStacks",
          at = @At(
                  value = "INVOKE",
                  target = "Lnet/minecraft/block/entity/PistonBlockEntity;getPushedBlock()" +
                           "Lnet/minecraft/block/BlockState;"
          ),
          cancellable = true)
  private void getDroppedStacksForMovableBlock(class_2680 state,
                                               //#if MC>11904
                                               //#if MC>12101
                                               //$$ LootWorldContext.Builder builder,
                                               //#else
                                               //$$ LootContextParameterSet.Builder builder,
                                               //#endif
                                               //#else
                                               class_47.class_48 builder,
                                               //#endif
                                               CallbackInfoReturnable<List<class_1799>> cir,
                                               @Local class_2669 pistonBlockEntity) {
    List<class_1799> droppedStacks = UnobtainableBlockProcessor.getItemStacks(pistonBlockEntity);
    if (droppedStacks != null)
      cir.setReturnValue(droppedStacks);
  }
}

==> carpet-addons-not-found-1.21.1-2.2.0-sources.jar: carpetaddonsnotfound/mixins/PistonExtensionBlockMixin.java <==
package carpetaddonsnotfound.mixins;

import carpetaddonsnotfound.unobtainableblocks.UnobtainableBlockProcessor;
import com.llamalad7.mixinextras.sugar.Local;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;
import java.util.List;
import net.minecraft.class_1799;
import net.minecraft.class_2667;
import net.minecraft.class_2669;
import net.minecraft.class_2680;
import net.minecraft.class_8567;

@Mixin(class_2667.class)
public abstract class PistonExtensionBlockMixin {
  @Inject(
          method = "getDroppedStacks",
          at = @At(
                  value = "INVOKE",
                  target = "Lnet/minecraft/block/entity/PistonBlockEntity;getPushedBlock()" +
                           "Lnet/minecraft/block/BlockState;"
          ),
          cancellable = true)
  private void getDroppedStacksForMovableBlock(class_2680 state,
                                               //#if MC>11904
                                               //#if MC>12101
                                               //$$ LootWorldContext.Builder builder,
                                               //#else
                                               class_8567.class_8568 builder,
                                               //#endif
                                               //#else
                                               //$$ LootContext.Builder builder,
                                               //#endif
                                               CallbackInfoReturnable<List<class_1799>> cir,
                                               @Local class_2669 pistonBlockEntity) {
    List<class_1799> droppedStacks = UnobtainableBlockProcessor.getItemStacks(pistonBlockEntity);
    if (droppedStacks != null)
      cir.setReturnValue(droppedStacks);
  }
}
